/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is the Clippings extension for Mozilla Firefox.
 *
 * The Initial Developer of the Original Code is 
 * Alex Eng <ateng@users.sourceforge.net>.
 * Portions created by the Initial Developer are Copyright (C) 2005
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * ***** END LICENSE BLOCK ***** */

//
// Integration with host application
//


var gClippingsExec = {
  initOnStartup: false,

  newFromClipboard: function () 
  {
    var rv = gClippings.newFromClipboard();
    if (! rv) {
      alert("Clipboard is empty or does not contain textual data.");
    }
  },

  newFromSelection: function ()
  {
    var focusedWnd = document.commandDispatcher.focusedWindow;
    var selection = focusedWnd.getSelection();
    var selectionStr = selection.toString();

    if (selectionStr) {
      gClippings.newClippingFromText(selectionStr);	
    }
    else {
      alert("No text selected. Please select text first.");
    }
  },

  openClippingsManager: function () 
  {
    window.open('chrome://clippings/content/clippings.xul', 'clippings_wndobj',
		'chrome');
  },

  initClippingsPopup: function () 
  {
    var popup = document.getElementById("ae-clippings-popup");
    var rootNode = gClippings.RDFSvc.GetResource("http://clippings.mozdev.org/rdf/user-clippings");

    try {
      // If Clippings data file doesn't exist, it will be created automatically.
      if (! gClippings.dataSrc) {
	gClippings.dataSrc = gClippings.RDFSvc.GetDataSourceBlocking(gClippings.getCurrentProfileURL() + "/" + CLIPDAT_FILE_NAME);
      }
    }
    catch (e) {
      alert(e);
    }

    popup.database.AddDataSource(gClippings.dataSrc);

    try {
      gClippings.RDFContainer = gClippings.RDFContainerUtils.MakeSeq(gClippings.dataSrc, rootNode);
      gClippings.RDFContainer = gClippings.RDFContainer.QueryInterface(Components.interfaces.nsIRDFContainer);
    }
    catch (e) {
      alert(e);
    }

    popup.builder.rebuild();
    this.initOnStartup = true;
  },

  insertClippingText: function (aText) 
  {
    gClippings.copyTextToClipboard(aText);

    // Paste clipping.  The following function is defined in
    // "chrome://global/content/globalOverlay.js"
    goDoCommand("cmd_paste");
    // SIDE EFFECT: The clipping text will remain on the system clipboard.
  }
};


// Drag 'n drop support
var clippingsStatusBarObserver = {
  onDragOver: function (event, flavour, session)
  {
    event.target.setAttribute("ae-dnd", "true");
  },

  onDragExit: function (event, session)
  {
    event.target.removeAttribute("ae-dnd");
  },

  onDrop: function (event, transferData, session)
  {
    if (! gClippingsExec.initOnStartup) {
      // The RDF data source has to be initialized if it has not already been
      // done so, otherwise RDF node creation will fail, and the new Clippings
      // entry will never be created.
      // This initialization is done in the code for the Clippings popup menu's
      // `onpopupshowing' event handler.
      gClippingsExec.initClippingsPopup();
    }

    var text = transferData.data;
    var newEntryURI = gClippings.newClippingFromText(text);
  },

  getSupportedFlavours: function ()
  {
    var flavours = new FlavourSet();
    flavours.appendFlavour("text/unicode");
    return flavours;
  }
};

